package com.tencent.karaoketv.common.level

import android.content.Context
import com.tencent.karaoketv.common.cpu.DeviceInfo

/**
 * Copyright 2018 Tencent Inc. All Rights Reserved.
 * <p>
 * Detail:  TV分级策略
 * <p>
 * Author: glensun
 * Create on 2018/3/19.
 */
object TVLevel {

    /**
     * 获取CPU核心数
     * 获取异常时，返回-1
     */
    fun getCpuCoresCount(): Int {
        return DeviceInfo.getNumberOfCPUCores()
    }

    /**
     * 获取CPU最大主频
     * 获取异常时，返回0或者-1
     */
    fun getCpuFreqMaxKHz(): Int {
        return DeviceInfo.getCPUMaxFreqKHz()
    }

    /**
     * 获取系统内存大小
     * 获取异常时，返回0或者-1
     */
    fun getTotalMemory(context: Context): Long {
        return DeviceInfo.getTotalMemory(context).shr(20)
    }

    /**
     * 获取系统给app分配的最大内存空间，单位m
     * 获取异常时，返回0
     */
    fun getAppTotalMemory(): Long {
        return Runtime.getRuntime().maxMemory().shr(20)
    }

    /**
     * 计算当前设备的得分情况
     * launchTime-启动时间，单位MS
     */
    fun getLevelScore(context: Context, launchTime: Long): Double {
        val cpuCore = getCpuCoresCount()
        val cpuFreq = getCpuFreqMaxKHz()
        val totalMem = getTotalMemory(context)

        // 考虑启动时间的维度
        var launchScore = (7000 - launchTime) / 100

        // 小于2000就认为是满分了
        if (launchScore > 50) launchScore = 50

        // 小于0就认为是0分
        if (launchScore < 0) launchScore = 0

        if (cpuCore > 0 && cpuFreq > 0 && totalMem > 0) {
            // 三个值都能获取到，计算一个值
            var hardScore = (cpuCore * 1 + totalMem * 1.4 + cpuFreq * 1.1) / 60

            // 大于3000分就认为是满分了
            if (hardScore > 50)
                hardScore = 50.0

            return launchScore + hardScore
        } else {
            return launchScore * 2.0
        }
    }
}