package com.tencent.karaoketv.module.hospital.presenter

import android.os.Build
import android.os.Bundle
import android.os.Looper
import android.widget.TextView
import com.tencent.karaoketv.R
import com.tencent.karaoketv.R.string.hospital_switch_frame_monitor
import com.tencent.karaoketv.app.activity.base.BaseFragmentActivity
import com.tencent.karaoketv.common.KaraokeConfig
import com.tencent.karaoketv.common.KaraokeContext
import com.tencent.karaoketv.common.monitor.FrameMonitor
import com.tencent.karaoketv.common.network.wns.WnsSwitchEnvironmentAgent.EnvironmentType.*
import com.tencent.karaoketv.common.room.RoomManager
import com.tencent.karaoketv.module.feedback.business.FeedbackBusiness
import com.tencent.karaoketv.module.orderbyphone.business.PhoneConnectManager
import com.tencent.mediaplayer.audiooutput.ThirdPartyOutputManager
import com.tencent.qqmusiccommon.util.MLog

/**
 * Copyright 2018 Tencent Inc. All Rights Reserved.
 * <p>
 * Detail:
 * <p>
 * Author: glensun
 * Create on 2018/3/7.
 */
class HospitalActivity : BaseFragmentActivity() {

    private val TAG = "HospitalActivity"

    override fun onCreate(savedInstanceState: Bundle?) {
        MLog.d(TAG, "onCreate")
        super.onCreate(savedInstanceState)
        setContentView(R.layout.hospital_layout)

        UI {
            R.id.hospital_user_id.requestFocus()
            R.id.hospital_user_id.setText("UserID: ${KaraokeContext.getAccountManager().activeAccountId}")
            R.id.hospital_qua.setText("QUA: ${KaraokeContext.getKaraokeConfig().qua}")
            R.id.hospital_ip.setText("Wifi: ${PhoneConnectManager.getInstance().ssid}, IP: ${PhoneConnectManager.getInstance().ip}, Port: ${PhoneConnectManager.getInstance().port}")
            R.id.hospital_room.setText("RoomID: ${RoomManager.getInstance().roomId}, RoomKey: ${RoomManager.getInstance().roomKey}")
            R.id.hospital_bajin_version.setText(getString(R.string.hospital_bajin_version,ThirdPartyOutputManager.getInstance().bajinSDKVer))
            R.id.hospital_environment.setText(getCurrentEnvironment())
            R.id.hospital_environment.onClick {
                MLog.d(TAG, "on click hospital_environment")
                when (KaraokeConfig.Wns.getDefaultEnv()) {
                    WORK_ENVIROMENT.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "expe1", "expe2"))
                        KaraokeConfig.Wns.setDefaultEnv(EXPE1.value)
                    }
                    EXPE1.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "expe2", "test1"))
                        KaraokeConfig.Wns.setDefaultEnv(EXPE2.value)
                    }
                    EXPE2.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "test1", "test2"))
                        KaraokeConfig.Wns.setDefaultEnv(TEST1.value)
                    }
                    TEST1.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "test2", "misty"))
                        KaraokeConfig.Wns.setDefaultEnv(TEST2.value)
                    }
                    TEST2.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "misty", "work"))
                        KaraokeConfig.Wns.setDefaultEnv(MISTY.value)
                    }
                    MISTY.value -> {
                        R.id.hospital_environment.setText(getString(R.string.hospital_switch_environment_tip, "work", "expe1"))
                        KaraokeConfig.Wns.setDefaultEnv(WORK_ENVIROMENT.value)
                    }
                }
            }
            R.id.hospital_send_mail.onClick {
                FeedbackBusiness.feedbackHospitalToMail()
            }

            //初始化帧率检测的UI
            refreshFrameText()
            R.id.hospital_frame_monitor.onClick {
                if(Build.VERSION.SDK_INT < Build.VERSION_CODES.JELLY_BEAN){
                    return@onClick
                }
                //切换帧率检测开关
//                FrameMonitor.sInstance.switchFrameMonitorForRealTime(FrameMonitor.sInstance.TYPE_FRAME_MONITOR)
//                refreshFrameText()
            }
        }
    }

    //刷新帧率text
    private fun refreshFrameText(){
        if(FrameMonitor.sInstance.isShow()){
            R.id.hospital_frame_monitor.setText(resources.getString(hospital_switch_frame_monitor,"关"))
        }else{
            R.id.hospital_frame_monitor.setText(resources.getString(hospital_switch_frame_monitor,"开"))
        }
    }

    private fun getCurrentEnvironment(): String {
        return when (KaraokeConfig.Wns.getDefaultEnv()) {
            WORK_ENVIROMENT.value -> getString(R.string.hospital_switch_environment_tip, "work", "expe1")
            EXPE1.value -> getString(R.string.hospital_switch_environment_tip, "expe1", "expe2")
            EXPE2.value -> getString(R.string.hospital_switch_environment_tip, "expe2", "test1")
            TEST1.value -> getString(R.string.hospital_switch_environment_tip, "test1", "test2")
            TEST2.value -> getString(R.string.hospital_switch_environment_tip, "test2", "misty")
            MISTY.value -> getString(R.string.hospital_switch_environment_tip, "misty", "work")
            else -> ""
        }
    }

    // initUI
    fun UI(block: () -> Unit) {
        if (Thread.currentThread() === Looper.getMainLooper().thread) {
            // 主线程
            block()
        } else {
            runOnUiThread(block)
        }
    }

    // View.requestFocus
    fun Int.requestFocus() =
            findViewById(this)?.requestFocus()

    // TextView.setText
    fun Int.setText(text: String) {
        (findViewById(this) as TextView).text = text
    }

    // View.setOnClickListener
    fun Int.onClick(block: () -> Unit) {
        findViewById(this)?.setOnClickListener {
            block()
        }
    }
}